@@ -45,13 +45,18 @@ def test_service_config_directory(host, path):
      'heat',
      'horizon',
      'ironic',
+     'kafka',
      'magnum',
      'manila',
+     'mariadb',
+     'monasca',
      'murano',
      'neutron',
      'nova',
      'sahara',
-     'swift'])
+     'storm',
+     'swift',
+     'zookeeper'])
 def test_service_config_directory_absent(host, path):
     path = os.path.join('/etc/kolla/config', path)
     utils.test_path_absent(host, path)
