@@ -12,6 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import errno
 import logging
 import os
 import os.path
@@ -20,6 +21,7 @@ import subprocess
 import sys
 import tempfile
 
+from kayobe import exception
 from kayobe import utils
 from kayobe import vault
 
@@ -150,6 +152,13 @@ def build_args(parsed_args, playbooks,
     return cmd
 
 
+def _read_vault_password_file(vault_password_file):
+    """Return the password from a vault password file."""
+    vault_password = utils.read_file(vault_password_file)
+    vault_password = vault_password.strip()
+    return vault_password
+
+
 def run_playbooks(parsed_args, playbooks,
                   extra_vars=None, limit=None, tags=None, quiet=False,
                   verbose_level=None, check=None):
@@ -158,8 +167,20 @@ def run_playbooks(parsed_args, playbooks,
     cmd = build_args(parsed_args, playbooks,
                      extra_vars=extra_vars, limit=limit, tags=tags,
                      verbose_level=verbose_level, check=check)
+    env = os.environ.copy()
+    # If the Vault password has been specified via --vault-password-file,
+    # ensure the environment variable is set, so that it can be referenced by
+    # playbooks to generate the kolla-ansible passwords.yml file.
+    if vault.VAULT_PASSWORD_ENV not in env and parsed_args.vault_password_file:
+        vault_password = _read_vault_password_file(
+            parsed_args.vault_password_file)
+        env[vault.VAULT_PASSWORD_ENV] = vault_password
+    # If the configuration path has been specified via --config-path, ensure
+    # the environment variable is set, so that it can be referenced by
+    # playbooks.
+    env.setdefault(CONFIG_PATH_ENV, parsed_args.config_path)
     try:
-        utils.run_command(cmd, quiet=quiet)
+        utils.run_command(cmd, quiet=quiet, env=env)
     except subprocess.CalledProcessError as e:
         LOG.error("Kayobe playbook(s) %s exited %d",
                   ", ".join(playbooks), e.returncode)
@@ -205,3 +226,39 @@ def config_dump(parsed_args, host=None, hosts=None, var_name=None,
         return hostvars
     finally:
         shutil.rmtree(dump_dir)
+
+
+def install_galaxy_roles(parsed_args, force=False):
+    """Install Ansible Galaxy role dependencies.
+
+    Installs dependencies specified in kayobe, and if present, in kayobe
+    configuration.
+
+    :param parsed_args: Parsed command line arguments.
+    :param force: Whether to force reinstallation of roles.
+    """
+    LOG.info("Installing galaxy role dependencies from kayobe")
+    utils.galaxy_install("requirements.yml", "ansible/roles", force=force)
+
+    # Check for requirements in kayobe configuration.
+    kc_reqs_path = os.path.join(parsed_args.config_path,
+                                "ansible", "requirements.yml")
+    if not utils.is_readable_file(kc_reqs_path)["result"]:
+        LOG.info("Not installing galaxy role dependencies from kayobe config "
+                 "- requirements.yml not present")
+        return
+
+    LOG.info("Installing galaxy role dependencies from kayobe config")
+    # Ensure a roles directory exists in kayobe-config.
+    kc_roles_path = os.path.join(parsed_args.config_path,
+                                 "ansible", "roles")
+    try:
+        os.makedirs(kc_roles_path)
+    except OSError as e:
+        if e.errno != errno.EEXIST:
+            raise exception.Error("Failed to create directory ansible/roles/ "
+                                  "in kayobe configuration at %s: %s" %
+                                  (parsed_args.config_path, str(e)))
+
+    # Install roles from kayobe-config.
+    utils.galaxy_install(kc_reqs_path, kc_roles_path, force=force)
